package
Version:
v0.0.0-...-c29c528
Opens a new window with list of versions in this module.
Published: Jul 11, 2024
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type SMSRequest struct {
Message string `json:"message"`
Sender string `json:"sender"`
Recipients []smsRecipients `json:"recipients"`
Tags []string `json:"tags"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.