Documentation
¶
Index ¶
- Variables
- func RegisterSafeKabGarageServer(s grpc.ServiceRegistrar, srv SafeKabGarageServer)
- type Account
- func (*Account) Descriptor() ([]byte, []int)deprecated
- func (x *Account) GetAccessToken() string
- func (x *Account) GetAccessTokenExpiresAt() *timestamp.Timestamp
- func (x *Account) GetRefreshToken() string
- func (x *Account) GetRefreshTokenExpiresAt() *timestamp.Timestamp
- func (x *Account) GetSessionId() string
- func (*Account) ProtoMessage()
- func (x *Account) ProtoReflect() protoreflect.Message
- func (x *Account) Reset()
- func (x *Account) String() string
- type CreateAccountRequest
- func (*CreateAccountRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateAccountRequest) GetEmail() string
- func (x *CreateAccountRequest) GetPassword() string
- func (*CreateAccountRequest) ProtoMessage()
- func (x *CreateAccountRequest) ProtoReflect() protoreflect.Message
- func (x *CreateAccountRequest) Reset()
- func (x *CreateAccountRequest) String() string
- type CreateUserResponse
- func (*CreateUserResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateUserResponse) GetAccessToken() string
- func (x *CreateUserResponse) GetAccessTokenExpiresAt() *timestamp.Timestamp
- func (x *CreateUserResponse) GetRefreshToken() string
- func (x *CreateUserResponse) GetRefreshTokenExpiresAt() *timestamp.Timestamp
- func (x *CreateUserResponse) GetSessionId() string
- func (*CreateUserResponse) ProtoMessage()
- func (x *CreateUserResponse) ProtoReflect() protoreflect.Message
- func (x *CreateUserResponse) Reset()
- func (x *CreateUserResponse) String() string
- type LoginAccountRequest
- func (*LoginAccountRequest) Descriptor() ([]byte, []int)deprecated
- func (x *LoginAccountRequest) GetEmail() string
- func (x *LoginAccountRequest) GetPassword() string
- func (*LoginAccountRequest) ProtoMessage()
- func (x *LoginAccountRequest) ProtoReflect() protoreflect.Message
- func (x *LoginAccountRequest) Reset()
- func (x *LoginAccountRequest) String() string
- type LoginAccountResponse
- func (*LoginAccountResponse) Descriptor() ([]byte, []int)deprecated
- func (x *LoginAccountResponse) GetAccessToken() string
- func (x *LoginAccountResponse) GetAccessTokenExpiresAt() *timestamp.Timestamp
- func (x *LoginAccountResponse) GetRefreshToken() string
- func (x *LoginAccountResponse) GetRefreshTokenExpiresAt() *timestamp.Timestamp
- func (x *LoginAccountResponse) GetSessionId() string
- func (*LoginAccountResponse) ProtoMessage()
- func (x *LoginAccountResponse) ProtoReflect() protoreflect.Message
- func (x *LoginAccountResponse) Reset()
- func (x *LoginAccountResponse) String() string
- type SafeKabGarageClient
- type SafeKabGarageServer
- type UnimplementedSafeKabGarageServer
- type UnsafeSafeKabGarageServer
Constants ¶
This section is empty.
Variables ¶
var File_account_proto protoreflect.FileDescriptor
var File_rpc_create_account_proto protoreflect.FileDescriptor
var File_rpc_login_account_proto protoreflect.FileDescriptor
var File_service_safekab_garage_proto protoreflect.FileDescriptor
var SafeKabGarage_ServiceDesc = grpc.ServiceDesc{ ServiceName: "pb.SafeKabGarage", HandlerType: (*SafeKabGarageServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateAccount", Handler: _SafeKabGarage_CreateAccount_Handler, }, { MethodName: "LoginAccount", Handler: _SafeKabGarage_LoginAccount_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "service_safekab_garage.proto", }
SafeKabGarage_ServiceDesc is the grpc.ServiceDesc for SafeKabGarage service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterSafeKabGarageServer ¶
func RegisterSafeKabGarageServer(s grpc.ServiceRegistrar, srv SafeKabGarageServer)
Types ¶
type Account ¶
type Account struct {
SessionId string `protobuf:"bytes,1,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
AccessToken string `protobuf:"bytes,2,opt,name=access_token,json=accessToken,proto3" json:"access_token,omitempty"`
AccessTokenExpiresAt *timestamp.Timestamp `protobuf:"bytes,3,opt,name=access_token_expires_at,json=accessTokenExpiresAt,proto3" json:"access_token_expires_at,omitempty"`
RefreshToken string `protobuf:"bytes,4,opt,name=refresh_token,json=refreshToken,proto3" json:"refresh_token,omitempty"`
RefreshTokenExpiresAt *timestamp.Timestamp `` /* 128-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*Account) Descriptor
deprecated
func (*Account) GetAccessToken ¶
func (*Account) GetAccessTokenExpiresAt ¶
func (*Account) GetRefreshToken ¶
func (*Account) GetRefreshTokenExpiresAt ¶
func (*Account) GetSessionId ¶
func (*Account) ProtoMessage ¶
func (*Account) ProtoMessage()
func (*Account) ProtoReflect ¶
func (x *Account) ProtoReflect() protoreflect.Message
type CreateAccountRequest ¶
type CreateAccountRequest struct {
Email string `protobuf:"bytes,1,opt,name=email,proto3" json:"email,omitempty"`
Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
// contains filtered or unexported fields
}
func (*CreateAccountRequest) Descriptor
deprecated
func (*CreateAccountRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateAccountRequest.ProtoReflect.Descriptor instead.
func (*CreateAccountRequest) GetEmail ¶
func (x *CreateAccountRequest) GetEmail() string
func (*CreateAccountRequest) GetPassword ¶
func (x *CreateAccountRequest) GetPassword() string
func (*CreateAccountRequest) ProtoMessage ¶
func (*CreateAccountRequest) ProtoMessage()
func (*CreateAccountRequest) ProtoReflect ¶
func (x *CreateAccountRequest) ProtoReflect() protoreflect.Message
func (*CreateAccountRequest) Reset ¶
func (x *CreateAccountRequest) Reset()
func (*CreateAccountRequest) String ¶
func (x *CreateAccountRequest) String() string
type CreateUserResponse ¶
type CreateUserResponse struct {
SessionId string `protobuf:"bytes,1,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
AccessToken string `protobuf:"bytes,2,opt,name=access_token,json=accessToken,proto3" json:"access_token,omitempty"`
AccessTokenExpiresAt *timestamp.Timestamp `protobuf:"bytes,3,opt,name=access_token_expires_at,json=accessTokenExpiresAt,proto3" json:"access_token_expires_at,omitempty"`
RefreshToken string `protobuf:"bytes,4,opt,name=refresh_token,json=refreshToken,proto3" json:"refresh_token,omitempty"`
RefreshTokenExpiresAt *timestamp.Timestamp `` /* 128-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*CreateUserResponse) Descriptor
deprecated
func (*CreateUserResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateUserResponse.ProtoReflect.Descriptor instead.
func (*CreateUserResponse) GetAccessToken ¶
func (x *CreateUserResponse) GetAccessToken() string
func (*CreateUserResponse) GetAccessTokenExpiresAt ¶
func (x *CreateUserResponse) GetAccessTokenExpiresAt() *timestamp.Timestamp
func (*CreateUserResponse) GetRefreshToken ¶
func (x *CreateUserResponse) GetRefreshToken() string
func (*CreateUserResponse) GetRefreshTokenExpiresAt ¶
func (x *CreateUserResponse) GetRefreshTokenExpiresAt() *timestamp.Timestamp
func (*CreateUserResponse) GetSessionId ¶
func (x *CreateUserResponse) GetSessionId() string
func (*CreateUserResponse) ProtoMessage ¶
func (*CreateUserResponse) ProtoMessage()
func (*CreateUserResponse) ProtoReflect ¶
func (x *CreateUserResponse) ProtoReflect() protoreflect.Message
func (*CreateUserResponse) Reset ¶
func (x *CreateUserResponse) Reset()
func (*CreateUserResponse) String ¶
func (x *CreateUserResponse) String() string
type LoginAccountRequest ¶
type LoginAccountRequest struct {
Email string `protobuf:"bytes,1,opt,name=email,proto3" json:"email,omitempty"`
Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
// contains filtered or unexported fields
}
func (*LoginAccountRequest) Descriptor
deprecated
func (*LoginAccountRequest) Descriptor() ([]byte, []int)
Deprecated: Use LoginAccountRequest.ProtoReflect.Descriptor instead.
func (*LoginAccountRequest) GetEmail ¶
func (x *LoginAccountRequest) GetEmail() string
func (*LoginAccountRequest) GetPassword ¶
func (x *LoginAccountRequest) GetPassword() string
func (*LoginAccountRequest) ProtoMessage ¶
func (*LoginAccountRequest) ProtoMessage()
func (*LoginAccountRequest) ProtoReflect ¶
func (x *LoginAccountRequest) ProtoReflect() protoreflect.Message
func (*LoginAccountRequest) Reset ¶
func (x *LoginAccountRequest) Reset()
func (*LoginAccountRequest) String ¶
func (x *LoginAccountRequest) String() string
type LoginAccountResponse ¶
type LoginAccountResponse struct {
SessionId string `protobuf:"bytes,1,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
AccessToken string `protobuf:"bytes,2,opt,name=access_token,json=accessToken,proto3" json:"access_token,omitempty"`
RefreshToken string `protobuf:"bytes,4,opt,name=refresh_token,json=refreshToken,proto3" json:"refresh_token,omitempty"`
AccessTokenExpiresAt *timestamp.Timestamp `protobuf:"bytes,3,opt,name=access_token_expires_at,json=accessTokenExpiresAt,proto3" json:"access_token_expires_at,omitempty"`
RefreshTokenExpiresAt *timestamp.Timestamp `` /* 128-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*LoginAccountResponse) Descriptor
deprecated
func (*LoginAccountResponse) Descriptor() ([]byte, []int)
Deprecated: Use LoginAccountResponse.ProtoReflect.Descriptor instead.
func (*LoginAccountResponse) GetAccessToken ¶
func (x *LoginAccountResponse) GetAccessToken() string
func (*LoginAccountResponse) GetAccessTokenExpiresAt ¶
func (x *LoginAccountResponse) GetAccessTokenExpiresAt() *timestamp.Timestamp
func (*LoginAccountResponse) GetRefreshToken ¶
func (x *LoginAccountResponse) GetRefreshToken() string
func (*LoginAccountResponse) GetRefreshTokenExpiresAt ¶
func (x *LoginAccountResponse) GetRefreshTokenExpiresAt() *timestamp.Timestamp
func (*LoginAccountResponse) GetSessionId ¶
func (x *LoginAccountResponse) GetSessionId() string
func (*LoginAccountResponse) ProtoMessage ¶
func (*LoginAccountResponse) ProtoMessage()
func (*LoginAccountResponse) ProtoReflect ¶
func (x *LoginAccountResponse) ProtoReflect() protoreflect.Message
func (*LoginAccountResponse) Reset ¶
func (x *LoginAccountResponse) Reset()
func (*LoginAccountResponse) String ¶
func (x *LoginAccountResponse) String() string
type SafeKabGarageClient ¶
type SafeKabGarageClient interface {
CreateAccount(ctx context.Context, in *CreateAccountRequest, opts ...grpc.CallOption) (*CreateUserResponse, error)
LoginAccount(ctx context.Context, in *LoginAccountRequest, opts ...grpc.CallOption) (*LoginAccountResponse, error)
}
SafeKabGarageClient is the client API for SafeKabGarage service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewSafeKabGarageClient ¶
func NewSafeKabGarageClient(cc grpc.ClientConnInterface) SafeKabGarageClient
type SafeKabGarageServer ¶
type SafeKabGarageServer interface {
CreateAccount(context.Context, *CreateAccountRequest) (*CreateUserResponse, error)
LoginAccount(context.Context, *LoginAccountRequest) (*LoginAccountResponse, error)
// contains filtered or unexported methods
}
SafeKabGarageServer is the server API for SafeKabGarage service. All implementations must embed UnimplementedSafeKabGarageServer for forward compatibility
type UnimplementedSafeKabGarageServer ¶
type UnimplementedSafeKabGarageServer struct {
}
UnimplementedSafeKabGarageServer must be embedded to have forward compatible implementations.
func (UnimplementedSafeKabGarageServer) CreateAccount ¶
func (UnimplementedSafeKabGarageServer) CreateAccount(context.Context, *CreateAccountRequest) (*CreateUserResponse, error)
func (UnimplementedSafeKabGarageServer) LoginAccount ¶
func (UnimplementedSafeKabGarageServer) LoginAccount(context.Context, *LoginAccountRequest) (*LoginAccountResponse, error)
type UnsafeSafeKabGarageServer ¶
type UnsafeSafeKabGarageServer interface {
// contains filtered or unexported methods
}
UnsafeSafeKabGarageServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SafeKabGarageServer will result in compilation errors.